OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} breytti lykilorðinu þínu",
    "You changed your password" : "Þú breyttir lykilorðinu þínu",
    "Your password was reset by an administrator" : "Kerfisstjóri breytti lykilorðinu þínu",
    "{actor} changed your email address" : "{actor} breytti tölvupóstfanginu þínu",
    "You changed your email address" : "Þú breyttir tölvupóstfanginu þínu",
    "Your email address was changed by an administrator" : "Kerfisstjóri breytti tölvupóstfanginu þínu",
    "Security" : "Öryggi",
    "You successfully logged in using two-factor authentication (%1$s)" : "Þér tókst að skrá þig inn með tveggja-þrepa auðkenningu (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Innskráning með tveggja-þrepa auðkenningu mistókst (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Breyting hefur orðið á <strong>lykilorði</strong> eða <strong>tölvupóstfangi</strong> þínu",
    "Your apps" : "Forritin þín",
    "Enabled apps" : "Virk forrit",
    "Disabled apps" : "Óvirk forrit",
    "App bundles" : "Forritavöndlar",
    "Wrong password" : "Rangt lykilorð",
    "Saved" : "Vistað",
    "No user supplied" : "Enginn notandi gefinn",
    "Unable to change password" : "Ekki tókst að breyta lykilorði",
    "Authentication error" : "Villa við auðkenningu",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Settu inn endurheimtulykilorð kerfisstjóra, annars munu öll notandagögn tapast.",
    "Wrong admin recovery password. Please check the password and try again." : "Rangt endurheimtulykilorð kerfisstjóra, athugaðu lykilorðið og reyndu aftur.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil notandans.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "uppsetning eða uppfærsla forrita úr forritabúð eða með skýjasambandi",
    "Federated Cloud Sharing" : "Deiling með skýjasambandi",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL er að nota úrelda útgáfu af %s (%s). Uppfærðu stýrikerfið þitt, annars er hætt við að eiginleikar á borð við %s virki ekki sem skyldi.",
    "A problem occurred, please check your log files (Error: %s)" : "Vandamál kom upp, skoðaðu yfir annálana þína (Villa: %s)",
    "Migration Completed" : "Yfirfærslu lokið",
    "Group already exists." : "Hópur er þegar til.",
    "Unable to add group." : "Ekki tókst að bæta hóp við.",
    "Unable to delete group." : "Get ekki eytt hópi.",
    "Invalid SMTP password." : "Ógilt SMTP-lykilorð",
    "Well done, %s!" : "Vel gert, %s!",
    "If you received this email, the email configuration seems to be correct." : "Fyrst að þú fékkst þennan tölvupóst, þá lítur út fyrir að tölvupóstuppsetningin sé í lagi.",
    "Email setting test" : "Prófa tölvupóststillingar",
    "Email could not be sent. Check your mail server log" : "Ekki var hægt að senda póst. Skoðaðu annál póstþjónsins",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Vandamál kom upp við að senda tölvupóst. Farðu yfir stillingarnar þínar. (Villa: %s)",
    "You need to set your user email before being able to send test emails." : "Þú verður að gefa upp netfangið þitt svo að þú getir sent prófunarpósta.",
    "Invalid mail address" : "Ógilt tölvupóstfang",
    "No valid group selected" : "Enginn gildur hópur valinn",
    "A user with that name already exists." : "Nú þegar til notandi með þetta nafn.",
    "To send a password link to the user an email address is required." : "Til að fá sendan tengil á staðfestingu lykilorðs verður notandinn að hafa gefið upp tölvupóstfangið sitt.",
    "Unable to create user." : "Gat ekki búið til notanda.",
    "Unable to delete user." : "Get ekki eytt notanda.",
    "Error while enabling user." : "Villa við að virkja notanda.",
    "Error while disabling user." : "Villa við að gera notanda óvirkann.",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Til að sannprófa Twitter-aðganginn þinn, sendu þá eftirfarandi tíst á Twitter (gakktu úr skugga um að skeytinu sé ekki skipt í línur):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Til að sannprófa vefsvæðið þitt, vistaðu eftirfarandi efni á vefrótinni þinni (web-root) á '.well-known/CloudIdVerificationCode.txt' (gakktu úr skugga um að allur textinn sé í einni línu):",
    "Settings saved" : "Stillingar vistaðar",
    "Unable to change full name" : "Get ekki breytt fullu nafni",
    "Unable to change email address" : "Get ekki breytt tölvupóstfangi",
    "Your full name has been changed." : "Fullu nafni þínu hefur verið breytt.",
    "Forbidden" : "Bannað",
    "Invalid user" : "Ógildur notandi",
    "Unable to change mail address" : "Get ekki breytt tölvupóstfangi",
    "Email saved" : "Tölvupóstfang vistað",
    "%1$s changed your password on %2$s." : "%1$s breytti lykilorðinu þínu á %2$s.",
    "Your password on %s was changed." : "Lykilorðinu þínu á %s hefur verið breytt.",
    "Your password on %s was reset by an administrator." : "Kerfisstjóri breytti lykilorðinu þínu á %s.",
    "Password changed for %s" : "Lykilorð breyttist fyrir %s",
    "If you did not request this, please contact an administrator." : "Ef þú baðst ekki um þetta, hafðu þá samband við kerfisstjóra.",
    "Password for %1$s changed on %2$s" : "Lykilorð fyrir %1$s breyttist %2$s",
    "%1$s changed your email address on %2$s." : "%1$s breytti tölvupóstfanginu þínu þann %2$s.",
    "Your email address on %s was changed." : "Tölvupóstfanginu þínu á %s var breytt.",
    "Your email address on %s was changed by an administrator." : "Kerfisstjóri breytti tölvupóstfanginu þínu á %s.",
    "Email address changed for %s" : "Tölvupóstfang breyttist fyrir %s",
    "The new email address is %s" : "Nýja tölvupóstfangið er %s",
    "Email address for %1$s changed on %2$s" : "Lykilorð fyrir %1$s breyttist þann %2$s",
    "Welcome aboard" : "Velkomin um borð",
    "Welcome aboard %s" : "Velkomin um borð %s",
    "You have now an %s account, you can add, protect, and share your data." : "Þú ert núna með %s aðgang, þú getur bætt við, varið og deilt gögnunum þínum.",
    "Your username is: %s" : "Notandanafnið þitt er: %s",
    "Set your password" : "Stilltu lykilorðið þitt",
    "Go to %s" : "Farðu í %s",
    "Install Client" : "Setja upp biðlaraforrit",
    "Your %s account was created" : "%s notandaaðgangurinn þinn var búinn til",
    "Password confirmation is required" : "Þörf á staðfestingu lykilorðs",
    "Couldn't remove app." : "Gat ekki fjarlægt forrit.",
    "Couldn't update app." : "Gat ekki uppfært forrit.",
    "Are you really sure you want add {domain} as trusted domain?" : "Ertu viss um að þú viljir bæta \"{domain}\" við sem treystu léni?",
    "Add trusted domain" : "Bæta við treystu léni",
    "Migration in progress. Please wait until the migration is finished" : "Yfirfærsla er í gangi. Dokaðu við þar til henni er lokið",
    "Migration started …" : "Yfirfærsla hafin...",
    "Not saved" : "Ekki vistað",
    "Sending…" : "Sendi...",
    "Email sent" : "Tölvupóstur sendur",
    "Official" : "Opinbert",
    "All" : "Allt",
    "Update to %s" : "Uppfæra í %s",
    "_You have %n app update pending_::_You have %n app updates pending_" : ["Það er %n forritsuppfærsla í bið","Það eru %n forritauppfærslur í bið"],
    "No apps found for your version" : "Engin forrit fundust fyrir útgáfuna þína",
    "The app will be downloaded from the app store" : "Forritinu verður hlaðið niður úr forritabúðinni",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Opinber forrit eru þróuð af og innan samfélagsins. Þau bjóða upp á ýmsa kjarnaeiginleika og eru tilbúin til notkunar í raunvinnslu.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Samþykkt forrit eru þróuð af treystum forriturum og hafa gengist undir lauslegar öryggisprófanir. Þau eru í virku viðhaldi í opnum hugbúnaðarsöfnum og umsjónarmenn þeirra dæma þau nógu stöðug til notkunar í allri venjulegri vinnslu.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Þetta forrit hefur ekki verið öryggisprófað, er nýtt erða þekkt fyrir ótöðugleika við vissar aðstæður. Uppsetning er á þína ábyrgð.",
    "Disabling app …" : "Geri forrit óvirkt …",
    "Error while disabling app" : "Villa við að afvirkja forrit",
    "Disable" : "Gera óvirkt",
    "Enable" : "Virkja",
    "Enabling app …" : "Virkja forrit …",
    "Error while enabling app" : "Villa við að virkja forrit",
    "Error: This app can not be enabled because it makes the server unstable" : "Villa: ekki er hægt að virkja þetta forrit því það gerir þjóninn óstöðugan.",
    "Error: Could not disable broken app" : "Villa: gat ekki gert bilaða forritið óvirkt",
    "Error while disabling broken app" : "Villa við að gera bilaða forritið óvirkt",
    "Updating...." : "Uppfæri...",
    "Error while updating app" : "Villa við að uppfæra forrit",
    "Updated" : "Uppfært",
    "Removing …" : "Fjarlægi ...",
    "Error while removing app" : "Villa við að fjarlægja forrit",
    "Remove" : "Fjarlægja",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Forritið hefur verið virkjað, en það þarf að uppfæra það. Þú verður áframsendur á uppfærslusíðuna eftir 5 sekúndur.",
    "App update" : "Uppfærsla forrits",
    "Approved" : "Samþykkt",
    "Experimental" : "Á tilraunastigi",
    "No apps found for {query}" : "Engin forrit fundust fyrir \"{query}",
    "Enable all" : "Virkja allt",
    "Allow filesystem access" : "Leyfa aðgang að skráakerfi",
    "Disconnect" : "Aftengjast",
    "Revoke" : "Afturkalla",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome fyrir Android",
    "iPhone iOS" : "iPhone iOS",
    "iPad iOS" : "iPad iOS",
    "iOS Client" : "iOS-biðlari",
    "Android Client" : "Android-biðlari",
    "Sync client - {os}" : "Samstilla bilara - {os}",
    "This session" : "Þessa setu",
    "Copy" : "Afrita",
    "Copied!" : "Afritað!",
    "Not supported!" : "Óstutt!",
    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
    "Error while loading browser sessions and device tokens" : "Villa við að hlaða inn vafrasetum og teiknum fyrir tæki",
    "Error while creating device token" : "Villa við að búa til teikn fyrir tækið",
    "Error while deleting the token" : "Villa kom upp við að eyða teikninu",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Villa kom upp. Sendu inn ASCII-kóðað PEM-skilríki.",
    "Valid until {date}" : "Gildir til {date}",
    "Delete" : "Eyða",
    "Local" : "Staðvært",
    "Private" : "Einka",
    "Only visible to local users" : "Einungis sýnilegt staðværum notendum",
    "Only visible to you" : "Einungis sýnilegt þér",
    "Contacts" : "Tengiliðir",
    "Visible to local users and to trusted servers" : "Sýnilegt staðværum notendum og á treystum þjónum",
    "Public" : "Opinbert",
    "Will be synced to a global and public address book" : "Verður samstillt víðværri og opinberri vistfangaskrá",
    "Verify" : "Sannreyna",
    "Verifying …" : "Sannreyni …",
    "An error occured while changing your language. Please reload the page and try again." : "Villa kom upp við að skipta um tungumálið þitt. Endurlestu síðuna og prófaðu aftur.",
    "Select a profile picture" : "Veldu einkennismynd",
    "Very weak password" : "Mjög veikt lykilorð",
    "Weak password" : "Veikt lykilorð",
    "So-so password" : "Svo-svo lykilorð",
    "Good password" : "Gott lykilorð",
    "Strong password" : "Sterkt lykilorð",
    "Groups" : "Hópar",
    "Unable to delete {objName}" : "Get ekki eytt {objName}",
    "Error creating group: {message}" : "Villa við að búa til hóp: {message}",
    "A valid group name must be provided" : "Skráðu inn gilt heiti á hópi",
    "deleted {groupName}" : "eyddi {groupName}",
    "undo" : "afturkalla",
    "{size} used" : "{size} notað",
    "never" : "aldrei",
    "deleted {userName}" : "eyddi {userName}",
    "No user found for <strong>{pattern}</strong>" : "Enginn notandi fannst fyrir <strong>{pattern}</strong>",
    "Unable to add user to group {group}" : "Tókst ekki að bæta notanda við hópinn {group}",
    "Unable to remove user from group {group}" : "Ekki tókst að fjarlægja notanda úr hópnum {group}",
    "Add group" : "Bæta við hópi",
    "Invalid quota value \"{val}\"" : "Óleyfilegt gildi kvóta \"{val}\"",
    "no group" : "enginn hópur",
    "Password successfully changed" : "Lykilorðinu hefur verið breytt",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Breyting á þessu lykilorði mun valda gagnatapi, þar sem gagnaendurheimt er ekki tiltæk fyrir þennan notanda",
    "Could not change the users email" : "Tókst ekki að breyta tölvupóstfangi notandans",
    "Error while changing status of {user}" : "Villa við að breyta stöðu {user}",
    "A valid username must be provided" : "Skráðu inn gilt notandanafn",
    "Error creating user: {message}" : "Villa við að búa til notanda: {message}",
    "A valid password must be provided" : "Skráðu inn gilt lykilorð",
    "A valid email must be provided" : "Skráðu inn gilt tölvupóstfang",
    "Developer documentation" : "Skjölun fyrir þróunaraðila",
    "View in store" : "Skoða í hugbúnaðarsafni",
    "Limit to groups" : "Takmarka við hópa",
    "This app has an update available." : "Uppfærsla er tiltæk fyrir þetta forrit.",
    "by %s" : "frá %s",
    "%s-licensed" : "%s-notkunarleyfi",
    "Documentation:" : "Hjálparskjöl:",
    "User documentation" : "Hjálparskjöl notenda",
    "Admin documentation" : "Hjálparskjöl kerfisstjóra",
    "Visit website" : "Heimsækja vefsvæðið",
    "Report a bug" : "Tilkynna um villu",
    "Show description …" : "Birta lýsingu …",
    "Hide description …" : "Fela lýsingu …",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina lágmarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina hámarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ekki var hægt að setja upp forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar:",
    "Enable only for specific groups" : "Einungis fyrir sérstaka hópa",
    "SSL Root Certificates" : "SSL-rótarskilríki",
    "Common Name" : "Almennt heiti",
    "Valid until" : "Gildir til",
    "Issued By" : "Gefið út af",
    "Valid until %s" : "Gildir til %s",
    "Import root certificate" : "Flytja inn rótarskilríki",
    "Administrator documentation" : "Hjálparskjöl stjórnanda",
    "Online documentation" : "Handbækur/skjölun á netinu",
    "Forum" : "Vefspjall",
    "Getting help" : "Til að fá hjálp",
    "Commercial support" : "Gjaldskyld tækniaðstoð",
    "None" : "Ekkert",
    "Login" : "Innskráning",
    "Plain" : "Einfalt",
    "NT LAN Manager" : "NT LAN stjórnun",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Póstþjónn",
    "Open documentation" : "Opna hjálparskjöl",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Það er mikilvægt að setja þennan vefþjón upp þannig að hann getir sent tölvupóst, eins og fyrir endurstillingu lykilorða og útsendingu tilkynninga.",
    "Send mode" : "Sendihamur",
    "Encryption" : "Dulritun",
    "From address" : "Frá vistfangi",
    "mail" : "póstur",
    "Authentication method" : "Auðkenningarmáti",
    "Authentication required" : "Auðkenningar krafist",
    "Server address" : "Vistfang þjóns",
    "Port" : "Gátt",
    "Credentials" : "Auðkenni",
    "SMTP Username" : "SMTP-notandanafn",
    "SMTP Password" : "SMTP-lykilorð",
    "Store credentials" : "Geyma auðkenni",
    "Test email settings" : "Prófa tölvupóststillingar",
    "Send email" : "Senda tölvupóst",
    "Server-side encryption" : "Dulritun á þjóni",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Dulritun á vefþjóni (server-side encryption) gerir kleift að dulrita skrár sem sendar eru inn á þennan þjón. Sá eiginleiki er ekki án áhrifa á afköst kerfisins, þannig að slíkt ætti ekki að virkja nema að vel yfirlögðu máli.",
    "Enable server-side encryption" : "Virkja dulritun á þjóni",
    "Please read carefully before activating server-side encryption: " : "Lestu eftirfarandi gaumgæfilega áður en þú virkjar dulritun á þjóni: ",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Þegar dulritun er virkjuð, munu frá þeim tímapunkti allar skrár sem sendar eru inn á þjóninn verða dulritaðar inni á honum. Einungis mun verða hægt að afvirkja dulritun síðar, ef virka dulritunareiningin styður þá aðgerð, og ef allar forsendur (t.d. að setja endurheimtulykil) eru uppfylltar.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Dulritun ein og sér tryggir ekki öryggi kerfisins. Endilega skoðaðu hjálparskjölin um hvernig dulritunarforritið virkar, og dæmi um hvaða uppsetningar eru studdar.",
    "Be aware that encryption always increases the file size." : "Hafðu í huga að dulritun eykur alltaf skráastærð.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Það er góður siður að taka regluleg öryggisafrit af gögnunum þínum; ef um dulrituð gögn er að ræða, gakktu úr skugga um að einnig sé tekið öryggisafrit af dulritunarlyklum ásamt gögnunum.",
    "This is the final warning: Do you really want to enable encryption?" : "Þetta er lokaaðvörun: Viltu örugglega virkja dulritun?",
    "Enable encryption" : "Virkja dulritun",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Engin dulritunareining hlaðin inn, virkjaðu dulritunareiningu í valmynd forritsins.",
    "Select default encryption module:" : "Veldu sjálfgefna dulritunareiningu:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju. Virkjaðu \"Sjálfgefna dulritunareiningu\" og keyrðu 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju.",
    "Start migration" : "Hefja yfirfærslu",
    "Security & setup warnings" : "Öryggi og aðvaranir vegna uppsetningar",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the Tips & Tricks section and the documentation for more information." : "Það er mikilvægt fyrir öryggi og afköst uppsetningarinnar þinnar að allt sé rétt stillt. Til að hjálpa við að svo sé, eru gerðar ýmsar sjálfvirkar prófanir. Skoðaðu 'Ábendingar og góð ráð' (Tips & Tricks) og hjálparskjölin til að sjá ítarlegar upplýsingar.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Það lítur út eins og að PHP sé ekki rétt sett upp varðandi fyrirspurnir um umhverfisbreytur. Prófun með getenv(\"PATH\") skilar auðu svari.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Endilega skoðaðu <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjöl uppsetningarinnar ↗</a> varðandi athugasemdir vegna uppsetningar PHP og sjálfa uppsetningu PHP-þjónsins, Sérstaklega ef þú notar php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Skrifvarða stillingaskráin hefur verið virkjuð. Þetta kemur í veg fyrir að hægt sé að sýsla með sumar stillingar í gegnum vefviðmótið. Að auki þarf þessi skrá að vera skrifanleg við hverja uppfærslu.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP virðist vera sett upp to fjarlægja innantextablokkir (inline doc blocks). Þetta mun gera ýmis kjarnaforrit óaðgengileg.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Þessu veldur væntanlega biðminni/hraðall á borð við Zend OPcache eða eAccelerator.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Gagnagrunnurinn keyrir ekki með \"READ COMMITTED\" færsluaðgreiningarstiginu. Þetta getur valdið vandamálum þegar margar aðgerðir eru keyrðar í einu.",
    "%1$s below version %2$s is installed, for stability and performance reasons it is recommended to update to a newer %1$s version." : "%1$s eldra en útgáfa %2$s er uppsett, en vegna stöðugleika og afkasta mælum við með að útgáfa %1$s verði sett upp.",
    "The PHP module 'fileinfo' is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP-eininguna 'fileinfo' vantar. Við mælum eindregið með notkun þessarar einingar til að fá bestu útkomu við greiningu á MIME-skráagerðum.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Færslulæsing skráa (transactional file locking) er óvirk, þetta gæti leitt til vandamála út frá forgangsskilyrðum (race conditions). Virkjaðu 'filelocking.enabled' í config.php til að forðast slík vandamál. Skoðaðu <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjölin ↗</a> til að sjá nánari upplýsingar.",
    "System locale can not be set to a one which supports UTF-8." : "Ekki var hægt að setja staðfærslu kerfisins á neina sem styður UTF-8.",
    "This means that there might be problems with certain characters in filenames." : "Þetta þýðir að það geta komið upp vandamál við að birta ákveðna stafi í skráaheitum.",
    "It is strongly proposed to install the required packages on your system to support one of the following locales: %s." : "Við mælum eindregið með því að þessir nauðsynlegu pakkar séu á kerfinu til stuðnings einnar af eftirfarandi staðfærslum: %s",
    "If your installation is not installed at the root of the domain and uses system Cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ef uppsetningin þín er ekki á rót lénsins og þú notar cron stýrikerfisins, þá geta komið upp vandamál við gerð URL-slóða. Til að forðast slík vandamál, skaltu stilla \"overwrite.cli.url\" valkostinn í config.php skránni þinni á slóð vefrótarinnar (webroot) í uppsetningunni (tillaga: \"%s\")",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ekki var hægt að keyra cron-verkið á skipanalínu. Eftirfarandi tæknilegar villur komu upp:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "Yfirfarðu vandlega <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">uppsetningarleiðbeiningarnar ↗</a>, og athugaðu hvort nokkrar villumeldingar eða aðvaranir séu í <a href=\"%s\">annálnum</a>.",
    "All checks passed." : "Stóðst allar prófanir.",
    "Background jobs" : "Verk í bakgrunni",
    "Last job ran %s." : "Síðasta verk var keyrt %s.",
    "Last job execution ran %s. Something seems wrong." : "Síðasta verk var keyrt %s. Eitthvað er ekki eins og það á að sér að vera.",
    "Background job didn’t run yet!" : "Bakgrunnsverk hefur ekki ennþá verið keyrt!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Til að ná bestum afköstum er mikilvægt að stilla bakgrunnsverk rétt. Fyrir stórar uppsetningar er mælt með því að nota 'cron' kerfisins. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
    "Execute one task with each page loaded" : "Framkvæma eitt verk með hverri innhlaðinni síðu",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 15 mínútna fresti yfir HTTP.",
    "Use system cron service to call the cron.php file every 15 minutes." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 15 mínútna fresti.",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php verður að vera keyrt af kerfisnotandanum \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Til að keyra þetta þarftu að hafa PHP-POSIX-viðaukann (extension). Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
    "Version" : "Útgáfa",
    "Sharing" : "Deiling",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Sem stjórnandi geturðu fínstillt hegðun við deilingu. Endilega kíktu á hjálparskjölin til að sjá ítarlegri upplýsingar.",
    "Allow apps to use the Share API" : "Leyfa forritum að nota Share API",
    "Allow users to share via link" : "Leyfa notendum að deila með tengli",
    "Allow public uploads" : "Leyfa opinberar innsendingar",
    "Always ask for a password" : "Alltaf biðja um lykilorð",
    "Enforce password protection" : "Krefjast verndunar með aðgangsorði",
    "Set default expiration date" : "Setja sjálfgefinn gildistíma",
    "Expire after " : "Rennur út eftir ",
    "days" : "daga",
    "Enforce expiration date" : "Krefjast dagsetningar á gildistíma",
    "Allow resharing" : "Leyfa endurdeilingu",
    "Allow sharing with groups" : "Leyfa deilingu með hópum",
    "Restrict users to only share with users in their groups" : "Takmarka notendur við að deila með notendum í þeirra eigin hópum",
    "Exclude groups from sharing" : "Undanskilja hópa frá því að deila",
    "These groups will still be able to receive shares, but not to initiate them." : "Þessir hópar munu samt geta tekið við deildum sameignum, en ekki geta útbúið þær.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Leyfa sjálfklárun notandanafns í deilingarglugga. Ef þetta er óvirkt þarf að setja inn fullt nafn notanda.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Birta fyrirvara á opinberu upphleðslusíðunni. (Birtist einungis þegar listi yfir skrár er falinn).",
    "This text will be shown on the public link upload page when the file list is hidden." : "Þessi texti birtist á opinberu upphleðslusíðunni þegar listi yfir skrár er falinn.",
    "Tips & tricks" : "Ábendingar og góð ráð",
    "There are a lot of features and config switches available to optimally customize and use this instance. Here are some pointers for more information." : "Það eru margir eiginleikar og stillingarofar í boði til að sérsníða og besta notkun þessarar uppsetningar. Hér eru nokkrar ábendingar um frekari upplýsingar.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Núna er stuðst við SQLite sem bakenda fyrir gagnagrunn. Fyrir stærri uppsetningar mælum við með að skipta yfir í annan gagnagrunnsbakenda.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Mælt er sérstaklega með þessu þegar skjáborðsforritið er notað til að samstilla skrár.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Til að yfirfæra í annan gagnagrunn skaltu nota skipanalínutólið: 'occ db:convert-type', eða lesa <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjölin ↗</a>.",
    "How to do backups" : "Hvernig á að taka öryggisafrit",
    "Advanced monitoring" : "Ítarleg vöktun",
    "Performance tuning" : "Fínstilling afkasta",
    "Improving the config.php" : "Bæting á config.php skránni",
    "Theming" : "Þemu",
    "Check the security of your Nextcloud over our security scan" : "Athugaðu öryggi Nextcloud-skýsins með öryggisskönnun okkar",
    "Hardening and security guidance" : "Brynjun og öryggisleiðbeiningar",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Þú notar <strong>%s</strong> af <strong>%s</strong>",
    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "You are using <strong>%s</strong> af <strong>%s</strong> (<strong>%s %%</strong>)",
    "Profile picture" : "Einkennismynd",
    "Upload new" : "Senda inn nýtt",
    "Select from Files" : "Veldu skrár",
    "Remove image" : "Fjarlægja mynd",
    "png or jpg, max. 20 MB" : "png eða jpg, hám. 20 MB",
    "Picture provided by original account" : "Mynd frá upprunalegum aðgangi",
    "Cancel" : "Hætta við",
    "Choose as profile picture" : "Veldu sem einkennismynd",
    "Full name" : "Fullt nafn",
    "No display name set" : "Ekkert birtingarnafn sett",
    "Email" : "Netfang",
    "Your email address" : "Netfangið þitt",
    "No email address set" : "Ekkert tölvupóstfang sett",
    "For password reset and notifications" : "Fyrir tilkynningar og endurstillingu lykilorðs",
    "Phone number" : "Símanúmer",
    "Your phone number" : "Símanúmerið þitt",
    "Address" : "Heimilisfang",
    "Your postal address" : "Heimilisfangið þitt",
    "Website" : "Vefsvæði",
    "It can take up to 24 hours before the account is displayed as verified." : "Það getur tekið allt að 24 klukkustundum áður en notandaaðgangurinn er birtur sem sannvottaður.",
    "Link https://…" : "Tengill https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter notandanafn @…",
    "You are member of the following groups:" : "Þú ert meðlimur eftirfarandi hópa:",
    "Language" : "Tungumál",
    "Help translate" : "Hjálpa við þýðingu",
    "Password" : "Lykilorð",
    "Current password" : "Núverandi lykilorð",
    "New password" : "Nýtt lykilorð",
    "Change password" : "Breyta lykilorði",
    "Web, desktop and mobile clients currently logged in to your account." : "Veftól, tölvur og símar sem núna eru skráð inn á aðganginn þinn.",
    "Device" : "Tæki",
    "Last activity" : "Síðasta virkni",
    "App name" : "Heiti forrits",
    "Create new app password" : "Búa til nýtt lykilorð forrits",
    "Use the credentials below to configure your app or device." : "Notaðu auðkennin hér fyrir neðan til að stilla forritið eða tækið.",
    "For security reasons this password will only be shown once." : "Af öryggisástæðum er þetta lykilorð einungis birt einu sinni.",
    "Username" : "Notandanafn",
    "Done" : "Lokið",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Þróað af {communityopen}Nextcloud samfélaginu{linkclose}, {githubopen}grunnkóðinn{linkclose} er gefinn út með {licenseopen}AGPL{linkclose} notkunarleyfinu.",
    "Follow us on Google+" : "Fylgstu með okkur á Google+",
    "Like our Facebook page" : "Líkaðu við Facebook-síðuna okkar",
    "Follow us on Twitter" : "Fylgstu með okkur á Twitter",
    "Check out our blog" : "Kíktu á bloggið okkar",
    "Subscribe to our newsletter" : "Gerstu áskrifandi að fréttabréfinu okkar",
    "Settings" : "Stillingar",
    "Show storage location" : "Birta staðsetningu gagnageymslu",
    "Show user backend" : "Birta bakenda notanda",
    "Show last login" : "Birta síðustu innskráningu",
    "Show email address" : "Birta tölvupóstfang",
    "Send email to new user" : "Senda tölvupóst til nýs notanda",
    "When the password of a new user is left empty, an activation email with a link to set the password is sent." : "Þegar lykilorð nýs notanda er skilið eftir autt, mun honum verða sendur tölvupóstur með tengli til að virkja aðganginn sinn.",
    "E-Mail" : "Tölvupóstfang",
    "Create" : "Búa til",
    "Admin Recovery Password" : "Endurheimtulykilorð kerfisstjóra",
    "Enter the recovery password in order to recover the users files during password change" : "Settu inn endurheimtulykilorð til að endurheimta skrár notandans við breytingu á lykilorði",
    "Group name" : "Heiti hóps",
    "Everyone" : "Allir",
    "Admins" : "Kerfisstjórar",
    "Disabled" : "Óvirkt",
    "Default quota" : "Sjálfgefinn kvóti",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Settu inn geymslukvóta (t.d.: \"512 MB\" eða \"12 GB\")",
    "Unlimited" : "ótakmörkuðu",
    "Other" : "Annað",
    "Group admin for" : "Hópstjóri fyrir",
    "Quota" : "Kvóti",
    "Storage location" : "Staðsetning gagnageymslu",
    "User backend" : "Bakendi notanda",
    "Last login" : "Síðasta innskráning",
    "change full name" : "breyta fullu nafni",
    "set new password" : "setja nýtt lykilorð",
    "change email address" : "breyta tölvupóstfangi",
    "Default" : "Sjálfgefið",
    "Enabled" : "Virkt",
    "Not enabled" : "Óvirkt",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Settu inn endurheimtulykilorð kerfisstjóra, annars munu öll notandagögn tapast",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil notandans.",
    "test email settings" : "prófa tölvupóststillingar",
    "Invalid request" : "Ógild fyrirspurn",
    "Admins can't remove themself from the admin group" : "Stjórnendur geta ekki fjarlægt sjálfa sig úr stjórnendahóp",
    "Unable to add user to group %s" : "Ekki tókst að bæta notanda við hópinn %s",
    "Unable to remove user from group %s" : "Ekki tókst að fjarlægja notanda úr hópnum %s",
    "Sending..." : "Sendi...",
    "Uninstalling ...." : "Tek út uppsetningu ....",
    "Error while uninstalling app" : "Villa við að fjarlægja forrit",
    "Uninstall" : "Henda út",
    "__language_name__" : "Íslenska",
    "Personal info" : "Persónulegar upplýsingar",
    "Sessions" : "Setur",
    "App passwords" : "Lykilorð forrita",
    "Sync clients" : "Samstilla biðlara",
    "This is used for sending out notifications." : "Þetta er notað til að senda út tilkynningar.",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Það lítur út eins og að PHP sé ekki rétt sett upp varðandi fyrirspurnir um umhverfisbreytur. Prófun með getenv(\"PATH\") skilar auðu svari.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Endilega skoðaðu <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjöl uppsetningarinnar ↗</a> varðandi athugasemdir vegna uppsetningar PHP og sjálfa uppsetningu PHP-þjónsins, Sérstaklega ef þú notar php-fpm.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP virðist vera sett upp to fjarlægja innantextablokkir (inline doc blocks). Þetta mun gera ýmis kjarnaforrit óaðgengileg.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s eldra en útgáfa %2$s er uppsett, en vegna stöðugleika og afkasta mælum við með að útgáfa %1$s verði sett upp.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-eininguna 'fileinfo' vantar. Við mælum eindregið með notkun þessarar einingar til að fá bestu útkomu við greiningu á MIME-skráagerðum.",
    "This means that there might be problems with certain characters in file names." : "Þetta þýðir að það geta komið upp vandamál við að birta ákveðna stafi í skráaheitum.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Við mælum eindregið með því að þessir nauðsynlegu pakkar séu á kerfinu til stuðnings einnar af eftirfarandi staðfærslum: %s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ef uppsetningin þín er ekki á rót lénsins og þú notar cron stýrikerfisins, þá geta komið upp vandamál við gerð URL-slóða. Til að forðast slík vandamál, skaltu stilla \"overwrite.cli.url\" valkostinn í config.php skránni þinni á slóð vefrótarinnar (webroot) í uppsetningunni (tillaga: \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Ekki var hægt að keyra cron-verkið á skipanalínu. Eftirfarandi tæknilegar villur komu upp:",
    "Cron" : "CRON",
    "Last cron job execution: %s." : "Síðasta keyrsla cron-verks: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Síðasta keyrsla cron-verks: %s. Eitthvað er ekki eins og það á að sér að vera.",
    "Cron was not executed yet!" : "Cron hefur ekki ennþá verið keyrt!",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 15 mínútna fresti yfir http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 15 mínútna fresti.",
    "To run this you need the PHP posix extension. See {linkstart}PHP documentation{linkend} for more details." : "Til að keyra þetta þarftu að hafa PHP-posix-viðaukann (extension). Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
    "Uninstall app" : "Henda út forriti",
    "Hey there,<br><br>just letting you know that you now have a %s account.<br><br>Your username: <strong>%s</strong><br>Access it: <strong><a href=\"%s\">%s</a></strong><br><br>" : "Hæ þú,<br><br>bara að láta þig vita að þú átt núna s aðgang.<br><br>Notandanafnið þitt: <strong>%s</strong><br>Tengstu honum: <strong><a href=\"%s\">%s</a></strong><br><br>",
    "Cheers!" : "Til hamingju!",
    "Hey there,\n\njust letting you know that you now have a %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hæ þú,\n\nbara að láta þig vita að þú átt núna %s aðgang.\n\nNotandanafnið þitt: %s\nTengstu honum: %s\n\n",
    "For password recovery and notifications" : "Fyrir tilkynningar og endurheimtingu lykilorðs",
    "Your website" : "Vefsvæðið þitt",
    "Your Twitter handle" : "Twitter notandanafnið þitt",
    "Get the apps to sync your files" : "Náðu í forrit til að samstilla skrárnar þínar",
    "Desktop client" : "Skjáborðsforrit",
    "Android app" : "Android-forrit",
    "iOS app" : "iOS-forrit",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Ef þú vilt styðja við verkefnið {contributeopen}taktu þátt í þróuninni {linkclose} eða {contributeopen}láttu orð út ganga{linkclose}!",
    "Show First Run Wizard again" : "Birta Fyrsta-skiptis-leiðarvísinn aftur",
    "Passcodes that give an app or device permissions to access your account." : "Aðgangskóði sem gefur forriti eða tæki heimild til að nota notandaaðganginn þinn.",
    "Name" : "Heiti",
    "Follow us on Google Plus!" : "Fylgstu með okkur á Google Plus!",
    "Like our facebook page!" : "Líkaðu við Facebook-síðuna okkar!",
    "Subscribe to our twitter channel!" : "Gerstu áskrifandi að twitter-rásinni okkar!",
    "Subscribe to our news feed!" : "Gerstu áskrifandi að fréttastraumi okkar!",
    "Subscribe to our newsletter!" : "Gerstu áskrifandi að fréttabréfinu okkar!",
    "Show last log in" : "Birta síðustu innskráningu",
    "Verifying" : "Sannreyni",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the Tips & Ticks section and the documentation for more information." : "Það er mikilvægt fyrir öryggi og afköst uppsetningarinnar þinnar að allt sé rétt stillt. Til að hjálpa við að svo sé, eru gerðar ýmsar sjálfvirkar prófanir. Skoðaðu 'Ábendingar og góð ráð' (Tips & Tricks) og hjálparskjölin til að sjá ítarlegar upplýsingar.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with MIME type detection." : "PHP-eininguna 'fileinfo' vantar. Við mælum eindregið með notkun þessarar einingar til að fá bestu útkomu við greiningu á MIME-skráagerðum.",
    "Web, desktop, mobile clients and app specific passwords that currently have access to your account." : "Veftól, tölvur, símar og sértæk lykilorð forrita sem núna hafa aðgang inn á aðganginn þinn.",
    "Here you can generate individual passwords for apps so you don’t have to give out your password. You can revoke them individually too." : "Hér geturðu útbúið sérstök lykilorð fyrir hvert forrit svo að þú þurfir ekki að gefa upp lykilorðið þitt. Þú getur líka afturkallað þau hvert fyrir sig.",
    "Follow us on Google+!" : "Fylgstu með okkur á Google+!",
    "Follow us on Twitter!" : "Fylgstu með okkur á Twitter!",
    "Check out our blog!" : "Kíktu á bloggið okkar!"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
